# leihs-ldap-authenticator

LDAP based authentication handler for Leihs

## Getting Started

Edit the configuration file `leihs-ldap.yml`.

```
❯ python -m venv venv
❯ . ./venv/bin/activate
❯ pip install -r requirements.txt
❯ python -m leihsldap
 * Serving Flask app 'leihsldap.web'
 * Debug mode: off
WARNING: This is a development server. Do not use it in a production deployment. Use a production WSGI server instead.
 * Running on http://127.0.0.1:5000
```
